==> cutter-0.9.0.tar.gz: cutter-0.9.0/cutter/cut-marshalers.h <==

#ifndef ___cut_marshal_MARSHAL_H__
#define ___cut_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:OBJECT,OBJECT (../cutter/cut-marshalers.list:1) */
extern void _cut_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,OBJECT (../cutter/cut-marshalers.list:2) */
extern void _cut_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:OBJECT,UINT (../cutter/cut-marshalers.list:3) */
extern void _cut_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,UINT,UINT (../cutter/cut-marshalers.list:4) */
extern void _cut_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:UINT,UINT (../cutter/cut-marshalers.list:5) */
extern void _cut_marshal_VOID__UINT_UINT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

G_END_DECLS

#endif /* ___cut_marshal_MARSHAL_H__ */

==> cutter-1.0.0.tar.gz: cutter-1.0.0/cutter/cut-marshalers.h <==

#ifndef ___cut_marshal_MARSHAL_H__
#define ___cut_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:OBJECT,OBJECT (../cutter/cut-marshalers.list:1) */
extern void _cut_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,OBJECT (../cutter/cut-marshalers.list:2) */
extern void _cut_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:OBJECT,UINT (../cutter/cut-marshalers.list:3) */
extern void _cut_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,UINT,UINT (../cutter/cut-marshalers.list:4) */
extern void _cut_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:UINT,UINT (../cutter/cut-marshalers.list:5) */
extern void _cut_marshal_VOID__UINT_UINT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:STRING,STRING (../cutter/cut-marshalers.list:6) */
extern void _cut_marshal_VOID__STRING_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

G_END_DECLS

#endif /* ___cut_marshal_MARSHAL_H__ */
